@@ -45,3 +45,12 @@ Client.prototype.getOsFloatingIps = function (callback) {
   });
 };
 
+Client.prototype.bootstrapOptions = function (options, keys) {
+  var result = {};
+
+  if (options.keyname || options.key_name) {
+    result.keyname = options.keyname || options.key_name;
+  }
+
+  return result;
+};
